InfraCheck
==========

Health check system designed to be easy to extend by not enforcing the programming language.
A single health check unit (let we call it later just 'check') can be written even in BASH.

Read more in the documentation at: https://readthedocs.org/projects/infracheck/badge/?version=latest
